@@ -1,3 +1,4 @@
+import re
 import shutil
 from abc import ABCMeta, abstractmethod
 from textwrap import wrap
@@ -31,15 +32,18 @@ try:
 except ImportError:
     img_to_ascii = None
 
-styles = {"single": "││┌─┐└─┘",
-          "double": "║║╔═╗╚═╝",
-          "grid": '||+-++-+',
-          "separated": '||+=++=+',
-          "rounded": "||.-.'-'",
-          "dots": "::......",
-          "simple": '  ======',
-          }
+styles = {
+    "single": "││┌─┐└─┘",
+    "double": "║║╔═╗╚═╝",
+    "grid": '||+-++-+',
+    "separated": '||+=++=+',
+    "rounded": "||.-.'-'",
+    "dots": "::......",
+    "simple": '  ======',
+    "copy": ('', '', "#", "-", "-", "", "", "")
+}
 
+ANSI_ESCAPE = re.compile(r'\x1B(?:[@-Z\\-_]|\[[0-?]*[ -/]*[@-~])')
 COLOR_SUPPORTED = supports_color()
 PYGMENTS_SUPPORTED = COLOR_SUPPORTED and pygments is not None
 
@@ -47,13 +51,15 @@ PYGMENTS_SUPPORTED = COLOR_SUPPORTED and pygments is not None
 def printable_cell(text, width=None, style='single', color=None, pygments_lexer=None):
     width = width or (shutil.get_terminal_size().columns - 1)
     style_l, style_r, style_ul, style_u, style_ur, style_dl, style_d, style_dr = styles[style]
+    space_l = ' ' if style_l else ''
+    space_r = ' ' if style_r else ''
 
     color_start, color_end = "", ""
     if color:
         color = 'WHITE' if color is None else color.upper()
         color_start, color_end = (vars(colorama.Fore)[color.upper()], colorama.Fore.RESET)
 
-    text_width = width - 2 - len(style_l) - len(style_r)
+    text_width = width - len(space_l) - len(space_r) - len(style_l) - len(style_r)
 
     code_lines = []
     for code_line in text.split('\n'):
@@ -66,13 +72,23 @@ def printable_cell(text, width=None, style='single', color=None, pygments_lexer=
 
     result = [color_start + style_ul + style_u * (width - len(style_ul) - len(style_ur)) + style_ur + color_end]
     result.extend([
-        f"{color_start}{style_l}{color_end}"
-        f" {line}{' ' * d} "
+        f"{color_start}{style_l}{color_end}" +
+        space_l + f"{line}{' ' * d}" + space_r +
         f"{color_start}{style_r}{color_end}"
         for line, d in zip(code_lines, diff)
     ])
     result.append(color_start + style_dl + style_d * (width - len(style_dl) - len(style_dr)) + style_dr + color_end)
-    return '\n'.join(result)
+    return '\n'.join(line.rstrip(' ') for line in result)
+
+
+def monochrome(text):
+    """
+    Source:
+    https://stackoverflow.com/questions/14693701/how-can-i-remove-the-ansi-escape-sequences-from-a-string-in-python
+
+    :param text: any text
+    """
+    return ANSI_ESCAPE.sub('', text)
 
 
 class ParserBase(metaclass=ABCMeta):
