@@ -1,5 +1,6 @@
 import os
 import json
+from pathlib import Path
 from copy import deepcopy
 from typing import Union, Any
 
@@ -11,12 +12,15 @@ except ImportError:
 
 from nbmanips.notebook_base import NotebookBase
 from nbmanips.selector import is_new_slide, has_slide_type, has_output_type
-from nbmanips.utils import write_ipynb, read_ipynb, dict_to_ipynb, get_ipynb_name
+from nbmanips.utils import write_ipynb, dict_to_ipynb, get_ipynb_name
+from nbmanips.utils import read_ipynb, read_dbc, read_zpln
 from nbmanips.cell_utils import PYGMENTS_SUPPORTED
 
 try:
+    import pygments.util
     from pygments.lexers import get_lexer_by_name
 except ImportError:
+    pygments = None
     get_lexer_by_name = None
 
 
@@ -181,6 +185,15 @@ class ExportMixin(NotebookBase):
         """
         return dict_to_ipynb(self.raw_nb)
 
+    def convert(self, exporter_name, path, *args, exporter_type='nbmanips', **kwargs):
+        assert exporter_type in {'nbmanips', 'nbconvert'}
+        if exporter_type == 'nbconvert':
+            return self.nbconvert(exporter_name, path, *args, **kwargs)
+
+        exporter = self.get_exporter(exporter_name, exporter_type=exporter_type)
+
+        return exporter.export(self, path, *args, **kwargs)
+
     def nbconvert(self, exporter_name, path, *args, template_name=None, **kwargs):
         notebook_node = self.to_notebook_node()
 
@@ -265,6 +278,27 @@ class ExportMixin(NotebookBase):
         return self.nbconvert('slides', path, reveal_scroll=scroll, reveal_transition=transition,
                               reveal_theme=theme, **kwargs)
 
+    def to_dbc(self, path, filename=None, name=None, language=None, version='NotebookV1'):
+        """
+        Exports Notebook to dbc archive file
+
+        :param path: path to export to
+        :param filename: filename of the notebook inside archive (e.i. notebook.python)
+        :param name: name of the notebook
+        :param language: language of the notebook
+        :param version: version of dbc file (default is NotebookV1)
+        :return:
+        """
+        self.convert(
+            'dbc',
+            path,
+            exporter_type='nbmanips',
+            filename=filename,
+            name=name,
+            language=language,
+            version=version,
+        )
+
     def _get_pygments_lexer(self, use_pygments):
         if use_pygments:
             pygments_lexer = self.metadata.get('language_info', {}).get('pygments_lexer', None)
@@ -279,24 +313,30 @@ class ExportMixin(NotebookBase):
         if get_lexer_by_name is None:
             raise ModuleNotFoundError("You need to install pygments first.\n pip install pygments")
 
-        return get_lexer_by_name(pygments_lexer)
+        try:
+            return get_lexer_by_name(pygments_lexer)
+        except pygments.util.ClassNotFound:
+            return None
 
     def to_str(self, width=None, exclude_output=False, use_pygments=None, style='single', border_color=None,
-               parsers=None, parsers_config=None, excluded_data_types=None):
+               parsers=None, parsers_config=None, excluded_data_types=None, truncate=None):
         use_pygments = PYGMENTS_SUPPORTED if use_pygments is None else use_pygments
         pygments_lexer = self._get_pygments_lexer(use_pygments)
 
-        return '\n'.join(cell.to_str(
-            width=width,
-            exclude_output=exclude_output,
-            use_pygments=use_pygments,
-            pygments_lexer=pygments_lexer,
-            style=style,
-            color=border_color,
-            parsers=parsers,
-            parsers_config=parsers_config,
-            excluded_data_types=excluded_data_types,
-        ) for cell in self.iter_cells())
+        return '\n'.join(
+            cell.to_str(
+                width=width,
+                exclude_output=exclude_output,
+                use_pygments=use_pygments,
+                pygments_lexer=pygments_lexer,
+                style=style,
+                color=border_color,
+                parsers=parsers,
+                parsers_config=parsers_config,
+                excluded_data_types=excluded_data_types,
+                truncate=truncate,
+            ) for cell in self.iter_cells()
+        )
 
     def to_text(self, path, *args, **kwargs):
         """
@@ -318,7 +358,7 @@ class ExportMixin(NotebookBase):
         write_ipynb(self.raw_nb, path)
 
     def show(self, width=None, exclude_output=False, use_pygments=None, style='single', border_color=None,
-             parsers=None, parsers_config=None, excluded_data_types=None):
+             parsers=None, parsers_config=None, excluded_data_types=None, truncate=None):
         """
         Show the selected cells
         :param width:
@@ -338,21 +378,63 @@ class ExportMixin(NotebookBase):
             border_color=border_color,
             parsers=parsers,
             parsers_config=parsers_config,
-            excluded_data_types=excluded_data_types
+            excluded_data_types=excluded_data_types,
+            truncate=truncate,
         ))
 
     @classmethod
-    def read_ipynb(cls, path):
+    def read_ipynb(cls, path, name=None):
         """
         Read ipynb file
         :param path: path to the ipynb file
+        :param name: name of the Notebook
         :return: Notebook object
         """
         nb = read_ipynb(path)
-        return cls(nb, get_ipynb_name(path), validate=False)
+        return cls(nb, name or get_ipynb_name(path), validate=False)
+
+    @classmethod
+    def read_dbc(cls, path, filename=None, encoding='utf-8', name=None):
+        dbc_name, nb = read_dbc(path, filename=filename, encoding=encoding)
+        return cls(nb, name or dbc_name, validate=False)
+
+    @classmethod
+    def read_zpln(cls, path, encoding='utf-8', name=None):
+        zpln_name, nb = read_zpln(path, encoding=encoding)
+        return cls(nb, name or zpln_name, validate=False)
+
+    @classmethod
+    def read(cls, path, name=None, **kwargs):
+        readers = {
+            '.ipynb': cls.read_ipynb,
+            '.dbc': cls.read_dbc,
+            '.zpln': cls.read_zpln,
+        }
+
+        if not Path(path).exists():
+            raise FileNotFoundError(f'Could not find: {path}')
+
+        ext = Path(path).suffix.lower()
+        reader = readers.get(ext, None)
+        if reader:
+            return reader(path, name=name, **kwargs)
+
+        for reader in readers.values():
+            try:
+                return reader(path, name=name, **kwargs)
+            except Exception:
+                continue
+
+        raise ValueError('Could not determine the notebook type')
 
 
 class NotebookMetadata(NotebookBase):
+    @property
+    def language(self):
+        lang = self.metadata.get('kernelspec', {}).get('language', None)
+        lang = lang or self.metadata.get('language_info', {}).get('name', None)
+        return lang or self.metadata.get('language_info', {}).get('pygments_lexer', None)
+
     def add_author(self, name, **kwargs):
         """
         Add author to metadata
